@@ -31,9 +31,6 @@ from tests import ClientHTTPStubber
 SMOKE_TESTS = {
     'acm': {'ListCertificates': {}},
     'apigateway': {'GetRestApis': {}},
-    'application-autoscaling': {
-        'DescribeScalableTargets': {'ServiceNamespace': 'ecs'}
-    },
     'autoscaling': {
         'DescribeAccountLimits': {},
         'DescribeAdjustmentTypes': {},
@@ -107,11 +104,6 @@ SMOKE_TESTS = {
 # we've sent invalid params.
 ERROR_TESTS = {
     'apigateway': {'GetRestApi': {'restApiId': 'fake-id'}},
-    'application-autoscaling': {
-        'DescribeScalableTargets': {
-            'ServiceNamespace': 'fake-service-namespace'
-        }
-    },
     'autoscaling': {
         'CreateLaunchConfiguration': {
             'LaunchConfigurationName': 'foo',
